# Dobro

**Dobro** como próprio nome já diz, é uma bilbioteca que retorna o dobro de um número em Python.

# Função

* `dobro.metodo(number)` - Recebe um número e retorna o dobro desse número através do método:
  - calc